/* Y o u r   D e s c r i p t i o n                       */
/*                            AppBuilder Photon Code Lib */
/*                                         Version 1.13X */

/* Standard headers */
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

/* Toolkit headers */
#include <Ph.h>
#include <Pt.h>
#include <Ap.h>

#include <photon/PhRender.h> 

/* Local headers */
#include "abimport.h"
#include "proto.h"

/* Application Options string */
const char ApOptions[] =
	AB_OPTIONS ""; /* Add your options in the "" */

#define PX_IMAGE_MODULES
#define PX_GIF_SUPPORT
#define PX_PCX_SUPPORT
#define PX_BMP_SUPPORT
#define PX_TGA_SUPPORT
#include <photon/PxImage.h>

#define DEFINE_GLOBALS
#include "global.h"

int
init( int argc, char *argv[] )

	{

	/* eliminate 'unreferenced' warnings */
	argc = argc, argv = argv;

    load_image();

	create_mc();

	return( Pt_CONTINUE );

	}


void
load_image()
{
	PxMethods_t methods;

	memset( &methods, 0, sizeof( PxMethods_t ) );
	methods.flags |= PX_LOAD;
	if (!(bgimage = PxLoadImage( "../bgimage_24.bmp", &methods )))
	{
		printf("Error getting image\n");
		exit(0);
	}
	// set image and button dimension to this image
	dim.h = bgimage->size.h;
	dim.w = bgimage->size.w;
	bytes_per_pixel = 3;    // force it to 3
}


void 
create_mc() 
{ 
	image = (PhImage_t *)malloc(sizeof(PhImage_t));

	memcpy( image, bgimage, sizeof(PhImage_t) );

    image->type = Pg_IMAGE_DIRECT_888; // 3 bytes per pixel 
	image->size.h = dim.h;
	image->size.w = dim.w;

    image->image = PgShmemCreate( 
                        dim.w * dim.h * bytes_per_pixel, 
                        NULL ); 
    mc = PmMemCreateMC( image, &dim, &translation ); 
    mc->dc.flags |= Ph_INLINE_SHMEM_OBJECTS;

	memcpy( image->image, bgimage->image, dim.w * dim.h * bytes_per_pixel ); 
} 


void 
copy_base_image(PhArea_t *area) 
{
int offset;      // offset counter into image ... from where to start copying
// int y;

/*
 - memcopy over the image  ... be sure the image types match. 
 - also note that direct color is preferred to palette-based

A PhArea_t pointer is given as described below:

      O--------------------------------------------------
      |                 dim.w                           |
      |    A pos.xy------------->                       |
      |           |                                     |
      |           |dim.h                                |
      |           V             .                       |
      |                                                 |
      ---------------------------------------------------

    O = image pointer base:  e.g. image->image or bgimage->image
    A = PhArea_t    pos.[xy] is upper left start point
	                dim.[wh] is size of area

The following assumptions are made:

- the two image areas have the same bpl and same resolution
- the areas being copied are in the same position within the image
- a complete line of 
*/
/*
	for ( y = area->pos.y; y < area->pos.y + area->size.h; y++ ) {
		offset = y * image->bpl;
		memcpy( image->image + offset, 
    	        bgimage->image + offset, 
        	    area->size.w * bytes_per_pixel );
	}
*/
	offset = area->pos.y * image->bpl;
	memcpy( image->image   + offset, 
    	    bgimage->image + offset, 
        	area->size.w * area->size.h * bytes_per_pixel );
} 

